Welcome to Flask Image Search's documentation!
==============================================

.. toctree::
    :maxdepth: 2

    readme
    installation
    usage
    contributing
    authors
    history
    flask_image_search

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
